pygeodesy.ltpTuples

Package pygeodesy :: Module ltpTuples |
[frames] | no frames]

# Module ltpTuples

Named, Local Tangent Plane (LTP) tuples.

Local coordinate classes XyzLocal, Enu, Ned and Aer and local coordinate tuples Local9Tuple, Xyz4Tuple, Enu4Tuple, Ned4Tuple, Aer4Tuple, ChLV9Tuple, ChLVEN2Tuple, ChLVYX2Tuple, ChLVyx2Tuple and Footprint5Tuple.

See Also: References in module ltp.

Version: 25.05.01

Classes
| _AbcBase (INTERNAL) Base class for classes `Aer` and `Ned`.
| Aer Local `Azimuth-Elevation-Range` (AER) in a local tangent plane.
| Aer4Tuple 4-Tuple `(azimuth, elevation, slantrange, ltp)`, all in `meter` except `ltp`.
| Attitude4Tuple 4-Tuple `(alt, tilt, yaw, roll)` with `altitude` in (positive) `meter` and `tilt`, `yaw` and `roll` in `degrees` representing the attitude of a plane or camera.
| Ned Local `North-Eeast-Down` (NED) location in a local tangent plane.
| Ned4Tuple 4-Tuple `(north, east, down, ltp)`, all in `meter` except `ltp`.
| XyzLocal Local `(x, y, z)` in a local tangent plane (LTP), also base class for local Enu.
| Xyz4Tuple 4-Tuple `(x, y, z, ltp)`, all in `meter` except `ltp`.
| Enu Local `Eeast-North-Up` (ENU) location in a local tangent plane.
| Enu4Tuple 4-Tuple `(east, north, up, ltp)`, in `meter` except `ltp`.
| Local9Tuple 9-Tuple `(x, y, z, lat, lon, height, ltp, ecef, M)` with local `x`, `y`, `z` all in `meter`, geodetic `lat`, `lon`, `height`, local tangent plane `ltp` (Ltp), `ecef` (Ecef9Tuple) with geocentric `x`, `y`, `z`, geodetic `lat`, `lon`, `height` and concatenated rotation matrix `M` (EcefMatrix) or `None`.
| Uvw 3-D `u-v-w` (UVW) components.
| Uvw3Tuple 3-Tuple `(u, v, w)`, in `meter`.
| Los A Line-Of-Sight (LOS) from a `LatLon` or `Cartesian` location.
| ChLV9Tuple 9-Tuple `(Y, X, h_, lat, lon, height, ltp, ecef, M)` with unfalsed Swiss (Y, X, h_) coordinates and height, all in `meter`, `ltp` either a ChLV, ChLVa or ChLVe instance and `ecef` (EcefKarney at Bern, Ch), otherwise like Local9Tuple.
| ChLVYX2Tuple 2-Tuple `(Y, X)` with unfalsed Swiss LV95 easting and norting in `meter`.
| ChLVEN2Tuple 2-Tuple `(E_LV95, N_LV95)` with falsed Swiss LV95 easting and norting in `meter (2_600_000, 1_200_000)` and origin at `Bern, Ch`.
| ChLVyx2Tuple 2-Tuple `(y_LV03, x_LV03)` with falsed Swiss LV03 easting and norting in `meter (600_000, 200_000)` and origin at `Bern, Ch`.
| Footprint5Tuple 5-Tuple `(center, upperleft, upperight, loweright, lowerleft)` with the `center` and 4 corners of the local projection of a `Frustum`, each an Xyz4Tuple, XyzLocal, `LatLon`, etc.

Variables
| __all__ = `_ALL_LAZY.ltpTuples`